@@ -9,11 +9,7 @@ paths = [
     ("get_schema", "/subjects/{subject}/versions/{version}", "GET"),
     ("check_version", "/subjects/{subject}", "POST"),
     ("get_by_id", "/schemas/ids/{schema_id}", "GET"),
-    (
-        "test_compatibility",
-        "/compatibility/subjects/{subject}/versions/{version}",
-        "POST",
-    ),
+    ("test_compatibility", "/compatibility/subjects/{subject}/versions/{version}", "POST"),
     ("update_compatibility", "/config/{subject}", "PUT"),
     ("get_compatibility", "/config/{subject}", "GET"),
 ]
